@@ -1,14 +1,14 @@
 from __future__ import absolute_import
-from __future__ import with_statement
 
 from kombu import Connection, Consumer, Exchange, Producer, Queue
-from kombu.transport.base import Message, StdChannel, Transport
+from kombu.five import text_t
+from kombu.message import Message
+from kombu.transport.base import StdChannel, Transport, Management
 
-from kombu.tests.utils import TestCase
-from kombu.tests.utils import Mock
+from kombu.tests.case import Case, Mock
 
 
-class test_StdChannel(TestCase):
+class test_StdChannel(Case):
 
     def setUp(self):
         self.conn = Connection('memory://')
@@ -38,13 +38,17 @@ class test_StdChannel(TestCase):
         )
 
 
-class test_Message(TestCase):
+class test_Message(Case):
 
     def setUp(self):
         self.conn = Connection('memory://')
         self.channel = self.conn.channel()
         self.message = Message(self.channel, delivery_tag=313)
 
+    def test_postencode(self):
+        with self.assertRaises(LookupError):
+            Message(self.channel, text_t('FOO'), postencode='ccyzz')
+
     def test_ack_respects_no_ack_consumers(self):
         self.channel.no_ack_consumers = set(['abc'])
         self.message.delivery_info['consumer_tag'] = 'abc'
@@ -84,8 +88,22 @@ class test_Message(TestCase):
         self.assertTrue(logger.critical.called)
         self.assertIn("Couldn't ack", logger.critical.call_args[0][0])
 
+    def test_reject_log_error_when_no_error(self):
+        reject = self.message.reject = Mock()
+        self.message.reject_log_error(Mock(), KeyError, requeue=True)
+        reject.assert_called_with(requeue=True)
 
-class test_interface(TestCase):
+    def test_reject_log_error_when_error(self):
+        reject = self.message.reject = Mock()
+        reject.side_effect = KeyError('foo')
+        logger = Mock()
+        self.message.reject_log_error(logger, KeyError)
+        reject.assert_called_with(requeue=False)
+        self.assertTrue(logger.critical.called)
+        self.assertIn("Couldn't reject", logger.critical.call_args[0][0])
+
+
+class test_interface(Case):
 
     def test_establish_connection(self):
         with self.assertRaises(NotImplementedError):
@@ -106,3 +124,23 @@ class test_interface(TestCase):
     def test_drain_events(self):
         with self.assertRaises(NotImplementedError):
             Transport(None).drain_events(None)
+
+    def test_heartbeat_check(self):
+        Transport(None).heartbeat_check(Mock(name='connection'))
+
+    def test_driver_version(self):
+        self.assertTrue(Transport(None).driver_version())
+
+    def test_register_with_event_loop(self):
+        Transport(None).register_with_event_loop(Mock(name='loop'))
+
+    def test_manager(self):
+        self.assertTrue(Transport(None).manager)
+
+
+class test_Management(Case):
+
+    def test_get_bindings(self):
+        m = Management(Mock(name='transport'))
+        with self.assertRaises(NotImplementedError):
+            m.get_bindings()
