@@ -33,13 +33,13 @@ class ExchangeType(object):
         raise NotImplementedError('subclass responsibility')
 
     def prepare_bind(self, queue, exchange, routing_key, arguments):
-        """Returns tuple of `(routing_key, regex, queue)` to be stored
+        """Return tuple of `(routing_key, regex, queue)` to be stored
         for bindings to this exchange."""
         return routing_key, None, queue
 
     def equivalent(self, prev, exchange, type,
                    durable, auto_delete, arguments):
-        """Returns true if `prev` and `exchange` is equivalent."""
+        """Return true if `prev` and `exchange` is equivalent."""
         return (type == prev['type'] and
                 durable == prev['durable'] and
                 auto_delete == prev['auto_delete'] and
@@ -108,7 +108,7 @@ class TopicExchange(ExchangeType):
 
 class FanoutExchange(ExchangeType):
     """The `fanout` exchange implements broadcast messaging by delivering
-    copies of all messages to all queues bound the the exchange.
+    copies of all messages to all queues bound to the exchange.
 
     To support fanout the virtual channel needs to store the table
     as shared state.  This requires that the `Channel.supports_fanout`
